#
# This file is part of Config-Model-Xorg
#
# This software is Copyright (c) 2007-2016 by Dominique Dumont.
#
# This is free software, licensed under:
#
#   The GNU Lesser General Public License, Version 2.1, February 1999
#
# Generated file. Do not edit

[
          [
            'name',
            'Xorg::InputDevice::KeyboardOptRules',
            'element',
            [
              'XkbModel',
              {
                'value_type' => 'enum',
                'warp' => {
                            'follow' => '- XkbRules',
                            'rules' => {
                                         'xorg' => {
                                                     'help' => {
                                                                 'gyration' => 'Gyration',
                                                                 'compaqik18' => 'Compaq Internet Keyboard (18 keys)',
                                                                 'logiaccess' => 'Logitech Access Keyboard',
                                                                 'itouchin' => 'Logitech iTouch keyboard Internet Navigator',
                                                                 'itouch' => 'Logitech iTouch',
                                                                 'rapidaccess2a' => 'IBM Rapid Access II (alternate option)',
                                                                 'rapidaccess' => 'IBM Rapid Access',
                                                                 'pc98' => 'PC-98xx Series',
                                                                 'yahoo' => 'Yahoo! Internet Keyboard',
                                                                 'pc102' => 'Generic 102-key (Intl) PC',
                                                                 'mx1998' => 'Memorex MX1998',
                                                                 'macintosh_old' => 'Macintosh Old',
                                                                 'hpzt11xx' => 'Hewlett-Packard Pavilion ZT11xx',
                                                                 'btc5113rf' => 'BTC 5113RF Multimedia',
                                                                 'hp6000' => 'Hewlett-Packard Omnibook 6000/6100',
                                                                 'btc9000a' => 'BTC 9000A',
                                                                 'rapidaccess2' => 'IBM Rapid Access II',
                                                                 'propeller' => 'Propeller Voyager (KTEZ-1000)',
                                                                 'compaqik13' => 'Compaq Internet Keyboard (13 keys)',
                                                                 'dell101' => 'Dell 101-key PC',
                                                                 'logiitc' => 'Logitech iTouch Cordless Keyboard (model Y-RB6)',
                                                                 'hp2505' => 'Hewlett-Packard SK-2505 Internet Keyboard',
                                                                 'cherrybluea' => 'Cherry Blue Line CyBo@rd (alternate option)',
                                                                 'microsoftprose' => 'Microsoft Internet Keyboard Pro, Swedish',
                                                                 'microsoftprooem' => 'Microsoft Natural Keyboard Pro OEM',
                                                                 'powerpcps2' => 'PowerPC PS/2',
                                                                 'logicdpa2' => 'Logitech Cordless Desktop Pro (alternate option2)',
                                                                 'brother' => 'Brother Internet Keyboard',
                                                                 'trust' => 'Trust Wireless Keyboard Classic',
                                                                 'logicfn' => 'Logitech Cordless Freedom/Desktop Navigator',
                                                                 'hpxe3gf' => 'Hewlett-Packard Omnibook XE3 GF',
                                                                 'dell' => 'Dell',
                                                                 'microsoft' => 'Microsoft Natural',
                                                                 'hp500fa' => 'Hewlett-Packard Omnibook 500 FA',
                                                                 'trustda' => 'Trust Direct Access Keyboard',
                                                                 'sk2500' => 'SK-2500',
                                                                 'samsung4510' => 'Samsung SDM 4510P',
                                                                 'logicdn' => 'Logitech Cordless Desktop Navigator',
                                                                 'logiik' => 'Logitech Internet Keyboard',
                                                                 'dtk2000' => 'DTK2000',
                                                                 'pc104' => 'Generic 104-key PC',
                                                                 'btc5090' => 'BTC 5090',
                                                                 'pc105' => 'Generic 105-key (Intl) PC',
                                                                 'a4techKBS8' => 'A4Tech KBS-8',
                                                                 'flexpro' => 'Keytronic FlexPro',
                                                                 'pc101' => 'Generic 101-key PC',
                                                                 'symplon' => 'Symplon PaceBook (tablet PC)',
                                                                 'samsung4500' => 'Samsung SDM 4500P',
                                                                 'cherryblue' => 'Cherry Blue Line CyBo@rd',
                                                                 'thinkpad' => 'IBM ThinkPad 560Z/600/600E/A22E',
                                                                 'azonaRF2300' => 'Azona RF2300 wireless Internet Keyboard',
                                                                 'chicony' => 'Chicony Internet Keyboard',
                                                                 'winbook' => 'Winbook Model XP5',
                                                                 'dexxa' => 'Dexxa Wireless Desktop Keyboard',
                                                                 'sven' => 'SVEN Ergonomic 2500',
                                                                 'a4techKB21' => 'A4Tech KB-21',
                                                                 'microsoftinet' => 'Microsoft Internet Keyboard',
                                                                 'presario' => 'Laptop/notebook Compaq (eg. Presario) Internet Keyboard',
                                                                 'logicdpa' => 'Logitech Cordless Desktop Pro (alternate option)',
                                                                 'everex' => 'Everex STEPnote',
                                                                 'ipaq' => 'Compaq iPaq Keyboard',
                                                                 'geniuscomfy2' => 'Genius Comfy KB-21e-Scroll',
                                                                 'airkey' => 'Acer AirKey V',
                                                                 'logicdp' => 'Logitech Cordless Desktop Pro',
                                                                 'sk6200' => 'SK-6200',
                                                                 'sk7100' => 'SK-7100',
                                                                 'microsoftmult' => 'Microsoft Wireless Multimedia Keyboard 1.0A',
                                                                 'logidak' => 'Logitech Deluxe Access Keyboard',
                                                                 'logicdo' => 'Logitech Cordless Desktop Optical',
                                                                 'armada' => 'Laptop/notebook Compaq (eg. Armada) Laptop Keyboard',
                                                                 'hp2501' => 'Hewlett-Packard SK-2501 Multimedia Keyboard',
                                                                 'btc9000' => 'BTC 9000',
                                                                 'logicdit' => 'Logitech Cordless Desktop iTouch',
                                                                 'microsoftpro' => 'Microsoft Natural Keyboard Pro / Microsoft Internet Keyboard Pro',
                                                                 'btc9001ah' => 'BTC 9001AH',
                                                                 'hp5xx' => 'Hewlett-Packard Omnibook 5xx',
                                                                 'toshiba_s3000' => 'Toshiba Satellite S3000',
                                                                 'microsoftoffice' => 'Microsoft Office Keyboard',
                                                                 'jp106' => 'Japanese 106-key',
                                                                 'chicony9885' => 'Chicony KB-9885',
                                                                 'sp_inet' => 'Super Power Multimedia Keyboard',
                                                                 'inspiron' => 'Laptop/notebook Dell Inspiron 8xxx',
                                                                 'scorpius' => 'Advance Scorpius KI',
                                                                 'honeywell_euroboard' => 'Honeywell Euroboard',
                                                                 'logiultrax' => 'Logitech Ultra-X Keyboard',
                                                                 'omnikey101' => 'Northgate OmniKey 101',
                                                                 'compaqeak8' => 'Compaq Easy Access Keyboard',
                                                                 'hpxt1000' => 'Hewlett-Packard Omnibook XT1000',
                                                                 'logiink' => 'Logitech Internet Navigator Keyboard',
                                                                 'ltcd' => 'Logitech Cordless Desktop',
                                                                 'diamond' => 'Diamond 9801 / 9802 series',
                                                                 'qtronix' => 'QTronix Scorpius 98N+',
                                                                 'macintosh' => 'Macintosh',
                                                                 'cymotionlinux' => 'Cherry CyMotion Master Linux',
                                                                 'hpxe3gc' => 'Hewlett-Packard Omnibook XE3 GC',
                                                                 'acpi' => 'ACPI Standard',
                                                                 'oretec' => 'Oretec MCK-800 MM/Internet keyboard',
                                                                 'microsoftprousb' => 'Microsoft Natural Keyboard Pro USB / Microsoft Internet Keyboard Pro',
                                                                 'btc5126t' => 'BTC 5126T',
                                                                 'hpi6' => 'Hewlett-Packard Internet Keyboard',
                                                                 'genius' => 'Genius Comfy KB-16M / Genius MM Keyboard KWD-910',
                                                                 'compaqik7' => 'Compaq Internet Keyboard (7 keys)',
                                                                 'ennyah_dkb1008' => 'Ennyah DKB-1008',
                                                                 'acer_tm_800' => 'Acer TravelMate 800',
                                                                 'cherryblueb' => 'Cherry CyMotion Master XPress',
                                                                 'sk1300' => 'SK-1300',
                                                                 'abnt2' => 'Brazilian ABNT2',
                                                                 'mx2750' => 'Memorex MX2750',
                                                                 'mx2500' => 'Memorex MX2500 EZ-Access Keyboard'
                                                               },
                                                     'default' => 'pc105',
                                                     'choice' => [
                                                                   'pc101',
                                                                   'pc102',
                                                                   'pc104',
                                                                   'pc105',
                                                                   'dell101',
                                                                   'everex',
                                                                   'flexpro',
                                                                   'microsoft',
                                                                   'omnikey101',
                                                                   'winbook',
                                                                   'jp106',
                                                                   'pc98',
                                                                   'a4techKB21',
                                                                   'a4techKBS8',
                                                                   'abnt2',
                                                                   'airkey',
                                                                   'acpi',
                                                                   'azonaRF2300',
                                                                   'scorpius',
                                                                   'brother',
                                                                   'btc5113rf',
                                                                   'btc5126t',
                                                                   'btc9000',
                                                                   'btc9000a',
                                                                   'btc9001ah',
                                                                   'btc5090',
                                                                   'cherryblue',
                                                                   'cherryblueb',
                                                                   'cherrybluea',
                                                                   'chicony',
                                                                   'chicony9885',
                                                                   'compaqeak8',
                                                                   'compaqik7',
                                                                   'compaqik13',
                                                                   'compaqik18',
                                                                   'cymotionlinux',
                                                                   'armada',
                                                                   'presario',
                                                                   'ipaq',
                                                                   'dell',
                                                                   'inspiron',
                                                                   'dexxa',
                                                                   'diamond',
                                                                   'dtk2000',
                                                                   'ennyah_dkb1008',
                                                                   'genius',
                                                                   'geniuscomfy2',
                                                                   'gyration',
                                                                   'hpi6',
                                                                   'hp2501',
                                                                   'hp2505',
                                                                   'hpxe3gc',
                                                                   'hpxe3gf',
                                                                   'hpxt1000',
                                                                   'hpzt11xx',
                                                                   'hp500fa',
                                                                   'hp5xx',
                                                                   'hp6000',
                                                                   'honeywell_euroboard',
                                                                   'rapidaccess',
                                                                   'rapidaccess2',
                                                                   'rapidaccess2a',
                                                                   'thinkpad',
                                                                   'logiaccess',
                                                                   'ltcd',
                                                                   'logicdit',
                                                                   'logicdp',
                                                                   'logicdpa',
                                                                   'logicdpa2',
                                                                   'logicdo',
                                                                   'logicfn',
                                                                   'logicdn',
                                                                   'logidak',
                                                                   'logiitc',
                                                                   'logiik',
                                                                   'itouch',
                                                                   'logiitc',
                                                                   'logiik',
                                                                   'logiink',
                                                                   'itouchin',
                                                                   'logiultrax',
                                                                   'mx1998',
                                                                   'mx2500',
                                                                   'mx2750',
                                                                   'microsoftinet',
                                                                   'microsoftpro',
                                                                   'microsoftprousb',
                                                                   'microsoftprooem',
                                                                   'microsoftprose',
                                                                   'microsoftoffice',
                                                                   'microsoftmult',
                                                                   'oretec',
                                                                   'propeller',
                                                                   'qtronix',
                                                                   'samsung4500',
                                                                   'samsung4510',
                                                                   'sk1300',
                                                                   'sk2500',
                                                                   'sk6200',
                                                                   'sk7100',
                                                                   'sp_inet',
                                                                   'sven',
                                                                   'symplon',
                                                                   'toshiba_s3000',
                                                                   'trust',
                                                                   'trustda',
                                                                   'yahoo',
                                                                   'macintosh',
                                                                   'macintosh_old',
                                                                   'powerpcps2',
                                                                   'acer_tm_800'
                                                                 ]
                                                   },
                                         'sgi' => {
                                                    'help' => {
                                                                'indy101' => 'SGI O2, Indigo^2 or Indy (101-key US)',
                                                                'pc101' => 'Generic 101-key PC',
                                                                'jp106' => 'Generic 106-key Japanese PC',
                                                                'flexpro' => 'Keytronic FlexPro',
                                                                'dell101' => 'Dell 101-key PC',
                                                                'microsoft' => 'Microsoft Natural',
                                                                'indy102' => 'SGI O2, Indigo^2 or Indy (102-key European)',
                                                                'omnikey101' => 'Northgate OmniKey 101',
                                                                'indy' => 'SGI O2, Indigo^2 or Indy',
                                                                'indy106' => 'SGI O2, Indigo^2 or Indy (106-key Japanese)',
                                                                'indigo' => 'SGI Indigo',
                                                                'indy104' => 'Generic 104-key PC',
                                                                'pc102' => 'Generic 102-key (European) PC',
                                                                'indy105' => 'Generic 105-key PC',
                                                                'indigo102' => 'SGI Indigo (102-key European)'
                                                              },
                                                    'choice' => [
                                                                  'indy',
                                                                  'indy101',
                                                                  'indy102',
                                                                  'indy104',
                                                                  'indy105',
                                                                  'indy106',
                                                                  'indigo',
                                                                  'indigo102',
                                                                  'dell101',
                                                                  'flexpro',
                                                                  'jp106',
                                                                  'microsoft',
                                                                  'omnikey101',
                                                                  'pc101',
                                                                  'pc102'
                                                                ]
                                                  },
                                         'sun' => {
                                                    'help' => {
                                                                'type4' => 'Sun Type4',
                                                                'type6_euro' => 'Sun Type6 European',
                                                                'type5_euro' => 'Sun Type5 European',
                                                                'type5' => 'Sun Type5',
                                                                'type6' => 'Sun Type6',
                                                                'type5_unix' => 'Sun Type5 Unix'
                                                              },
                                                    'choice' => [
                                                                  'type4',
                                                                  'type5',
                                                                  'type5_euro',
                                                                  'type5_unix',
                                                                  'type6',
                                                                  'type6_euro'
                                                                ]
                                                  },
                                         'xorg-it' => {
                                                        'help' => {
                                                                    'pc105' => '105-key (Intl) PC Generico',
                                                                    'everex' => 'Everex STEPnote',
                                                                    'jp106' => '106-key Giapponese',
                                                                    'pc101' => '101-key PC Generico',
                                                                    'flexpro' => 'Keytronic FlexPro',
                                                                    'dell101' => 'Dell 101-key PC',
                                                                    'microsoft' => 'Microsoft Natural',
                                                                    'winbook' => 'Winbook Modello XP5',
                                                                    'omnikey101' => 'Northgate OmniKey 101',
                                                                    'pc98' => 'PC-98xx Series',
                                                                    'pc102' => '102-key (Intl) PC Generico',
                                                                    'pc104' => '104-key PC Generico'
                                                                  },
                                                        'default' => 'pc105',
                                                        'choice' => [
                                                                      'microsoft',
                                                                      'dell101',
                                                                      'flexpro',
                                                                      'omnikey101',
                                                                      'pc101',
                                                                      'pc102',
                                                                      'pc104',
                                                                      'pc105',
                                                                      'jp106',
                                                                      'everex',
                                                                      'winbook',
                                                                      'pc98'
                                                                    ]
                                                      }
                                       }
                          },
                'type' => 'leaf'
              },
              'XkbLayout',
              {
                'value_type' => 'enum',
                'warp' => {
                            'follow' => '- XkbRules',
                            'rules' => {
                                         'xorg' => {
                                                     'help' => {
                                                                 'bd' => 'Bangladesh',
                                                                 'tr' => 'Turkish ',
                                                                 'mm' => 'Myanmar',
                                                                 'ru' => 'Russia',
                                                                 'sy' => 'Syria',
                                                                 'ro' => 'Romania',
                                                                 'dk' => 'Denmark',
                                                                 'az' => 'Azerbaijan',
                                                                 'br' => 'Brazil',
                                                                 'srp' => 'Serbian',
                                                                 'al' => 'Albania',
                                                                 'uz' => 'Uzbekistan',
                                                                 'ge' => 'Georgia',
                                                                 'gr' => 'Greece',
                                                                 'is' => 'Iceland',
                                                                 'mt' => 'Malta',
                                                                 'la' => 'Laos',
                                                                 'gb' => 'United Kingdom',
                                                                 'ch' => 'Switzerland',
                                                                 'bt' => 'Bhutan',
                                                                 'bg' => 'Bulgaria',
                                                                 'ara' => 'Arabic',
                                                                 'it' => 'Italy',
                                                                 'hu' => 'Hungary',
                                                                 'pl' => 'Poland',
                                                                 'ca' => 'Canada',
                                                                 'mao' => 'Maori',
                                                                 'se' => 'Sweden',
                                                                 'sk' => 'Slovakia',
                                                                 'il' => 'Israel',
                                                                 'pt' => 'Portugal',
                                                                 'ua' => 'Ukraine',
                                                                 'ba' => 'Bosnia and Herzegovina',
                                                                 'kg' => 'Kyrgyzstan',
                                                                 'es' => 'Spain',
                                                                 'no' => 'Norway',
                                                                 'lv' => 'Latvia',
                                                                 'fo' => 'Faroe Islands',
                                                                 'latam' => 'Latin American',
                                                                 'fr' => 'France',
                                                                 'in' => 'India',
                                                                 'th' => 'Thailand',
                                                                 'si' => 'Slovenia',
                                                                 'ie' => 'Ireland',
                                                                 'tj' => 'Tajikistan',
                                                                 'cz' => 'Czechia',
                                                                 'by' => 'Belarus',
                                                                 'fi' => 'Finland',
                                                                 'lt' => 'Lithuania',
                                                                 'hr' => 'Croatia',
                                                                 'ir' => 'Iran',
                                                                 'de' => 'Germany',
                                                                 'be' => 'Belgium',
                                                                 'jp' => 'Japan',
                                                                 'am' => 'Armenia',
                                                                 'us' => 'U.S. English',
                                                                 'vn' => 'Vietnam',
                                                                 'ee' => 'Estonia',
                                                                 'mkd' => 'Macedonian',
                                                                 'nec_vndr/jp' => 'PC-98xx Series',
                                                                 'pk' => 'Pakistan',
                                                                 'nl' => 'Netherlands',
                                                                 'mn' => 'Mongolia',
                                                                 'lk' => 'Sri Lanka'
                                                               },
                                                     'choice' => [
                                                                   'us',
                                                                   'ara',
                                                                   'al',
                                                                   'am',
                                                                   'az',
                                                                   'by',
                                                                   'be',
                                                                   'bd',
                                                                   'in',
                                                                   'ba',
                                                                   'br',
                                                                   'bg',
                                                                   'mm',
                                                                   'ca',
                                                                   'hr',
                                                                   'cz',
                                                                   'dk',
                                                                   'nl',
                                                                   'bt',
                                                                   'ee',
                                                                   'ir',
                                                                   'fo',
                                                                   'fi',
                                                                   'fr',
                                                                   'ge',
                                                                   'de',
                                                                   'gr',
                                                                   'hu',
                                                                   'is',
                                                                   'il',
                                                                   'it',
                                                                   'jp',
                                                                   'kg',
                                                                   'la',
                                                                   'latam',
                                                                   'lt',
                                                                   'lv',
                                                                   'mao',
                                                                   'mkd',
                                                                   'mt',
                                                                   'mn',
                                                                   'no',
                                                                   'pl',
                                                                   'pt',
                                                                   'ro',
                                                                   'ru',
                                                                   'srp',
                                                                   'si',
                                                                   'sk',
                                                                   'es',
                                                                   'se',
                                                                   'ch',
                                                                   'sy',
                                                                   'tj',
                                                                   'lk',
                                                                   'th',
                                                                   'tr',
                                                                   'ua',
                                                                   'gb',
                                                                   'uz',
                                                                   'vn',
                                                                   'nec_vndr/jp',
                                                                   'ie',
                                                                   'pk'
                                                                 ]
                                                   },
                                         'sgi' => {
                                                    'help' => {
                                                                'pt' => 'Portuguese',
                                                                'tr' => 'Turkish',
                                                                'en_US' => 'US/English w/ISO9995-3',
                                                                'jp' => 'Japanese',
                                                                'es' => 'Spanish',
                                                                'ru' => 'Russian',
                                                                'no' => 'Norwegian',
                                                                'fr' => 'French',
                                                                'gb' => 'United Kingdom',
                                                                'dk' => 'Danish',
                                                                'dvorak' => 'Dvorak (US)',
                                                                'us' => 'US/ASCII',
                                                                'th' => 'Thai',
                                                                'bg' => 'Bulgarian',
                                                                'fr_CH' => 'Swiss French',
                                                                'intl' => 'US w/Compose Key',
                                                                'it' => 'Italian',
                                                                'de_CH' => 'Swiss German',
                                                                'hu' => 'Hungarian',
                                                                'pl' => 'Polish',
                                                                'ca' => 'Canadian',
                                                                'sk_qwerty' => 'Slovak (qwerty)',
                                                                'cz' => 'Czech',
                                                                'fi' => 'Finnish',
                                                                'se' => 'Swedish',
                                                                'de' => 'German',
                                                                'cz_qwerty' => 'Czech (qwerty)',
                                                                'be' => 'Belgian',
                                                                'sk' => 'Slovak'
                                                              },
                                                    'choice' => [
                                                                  'be',
                                                                  'bg',
                                                                  'ca',
                                                                  'cz',
                                                                  'cz_qwerty',
                                                                  'de',
                                                                  'de_CH',
                                                                  'dvorak',
                                                                  'dk',
                                                                  'en_US',
                                                                  'es',
                                                                  'fi',
                                                                  'fr',
                                                                  'fr_CH',
                                                                  'gb',
                                                                  'hu',
                                                                  'it',
                                                                  'intl',
                                                                  'jp',
                                                                  'no',
                                                                  'pl',
                                                                  'pt',
                                                                  'ru',
                                                                  'se',
                                                                  'sk',
                                                                  'sk_qwerty',
                                                                  'th',
                                                                  'us',
                                                                  'tr'
                                                                ]
                                                  },
                                         'sun' => {
                                                    'help' => {
                                                                'pt' => 'Portuguese',
                                                                'tr' => 'Turkish',
                                                                'en_US' => 'US/English w/ISO9995-3',
                                                                'jp' => 'Japanese',
                                                                'es' => 'Spanish',
                                                                'ru' => 'Russian',
                                                                'no' => 'Norwegian',
                                                                'fr' => 'French',
                                                                'gb' => 'United Kingdom',
                                                                'dvorak' => 'Dvorak (US)',
                                                                'dk' => 'Danish',
                                                                'us' => 'US/ASCII',
                                                                'th' => 'Thai',
                                                                'bg' => 'Bulgarian',
                                                                'fr_CH' => 'Swiss French',
                                                                'it' => 'Italian',
                                                                'intl' => 'US w/Compose Key',
                                                                'de_CH' => 'Swiss German',
                                                                'hu' => 'Hungarian',
                                                                'pl' => 'Polish',
                                                                'ca' => 'Canadian',
                                                                'cz' => 'Czech',
                                                                'fi' => 'Finnish',
                                                                'se' => 'Swedish',
                                                                'de' => 'German',
                                                                'be' => 'Belgian',
                                                                'sk' => 'Slovak'
                                                              },
                                                    'choice' => [
                                                                  'be',
                                                                  'bg',
                                                                  'ca',
                                                                  'cz',
                                                                  'de',
                                                                  'de_CH',
                                                                  'dvorak',
                                                                  'dk',
                                                                  'en_US',
                                                                  'es',
                                                                  'fi',
                                                                  'fr',
                                                                  'fr_CH',
                                                                  'gb',
                                                                  'hu',
                                                                  'it',
                                                                  'intl',
                                                                  'jp',
                                                                  'no',
                                                                  'pl',
                                                                  'pt',
                                                                  'ru',
                                                                  'se',
                                                                  'sk',
                                                                  'th',
                                                                  'us',
                                                                  'tr'
                                                                ]
                                                  },
                                         'xorg-it' => {
                                                        'help' => {
                                                                    'pt' => 'Portoghese',
                                                                    'en_US' => 'U.S. Inglese + ISO9995-3',
                                                                    'jp' => 'Giapponese',
                                                                    'hu_qwerty' => 'Ungherese (qwerty)',
                                                                    'es' => 'Spagnolo',
                                                                    'ru' => 'Russo',
                                                                    'no' => 'Norvegese',
                                                                    'fr' => 'Francese',
                                                                    'gb' => 'Regno Unito',
                                                                    'dk' => 'Danese',
                                                                    'us' => 'Inglese Statunitense',
                                                                    'th' => 'Tailandese',
                                                                    'bg' => 'Bulgaro',
                                                                    'fr_CH' => 'Francese Svizzero',
                                                                    'it' => 'Italiano',
                                                                    'de_CH' => 'Tedesco Svizzero',
                                                                    'hu' => 'Ungherese',
                                                                    'pl' => 'Polacco',
                                                                    'ca' => 'Canadese',
                                                                    'sk_qwerty' => 'Slovacco (qwerty)',
                                                                    'cz' => 'Ceco',
                                                                    'nec/jp' => 'nec/jp(pc98)',
                                                                    'fi' => 'Finlandese',
                                                                    'se' => 'Svedese',
                                                                    'de' => 'Tedesco',
                                                                    'cz_qwerty' => 'Ceco (qwerty)',
                                                                    'be' => 'Belga',
                                                                    'sk' => 'Slovacco'
                                                                  },
                                                        'choice' => [
                                                                      'us',
                                                                      'en_US',
                                                                      'be',
                                                                      'bg',
                                                                      'ca',
                                                                      'cz',
                                                                      'cz_qwerty',
                                                                      'de',
                                                                      'de_CH',
                                                                      'dk',
                                                                      'es',
                                                                      'fi',
                                                                      'fr',
                                                                      'fr_CH',
                                                                      'gb',
                                                                      'hu',
                                                                      'hu_qwerty',
                                                                      'it',
                                                                      'jp',
                                                                      'no',
                                                                      'pl',
                                                                      'pt',
                                                                      'ru',
                                                                      'se',
                                                                      'sk',
                                                                      'sk_qwerty',
                                                                      'th',
                                                                      'nec/jp'
                                                                    ]
                                                      }
                                       }
                          },
                'default' => 'us',
                'type' => 'leaf'
              },
              'XkbVariant',
              {
                'value_type' => 'enum',
                'warp' => {
                            'follow' => [
                                          '- XkbRules',
                                          '- XkbLayout'
                                        ],
                            'rules' => [
                                         [
                                           'sgi',
                                           [
                                             'be',
                                             'bg',
                                             'ca',
                                             'cz',
                                             'cz_qwerty',
                                             'de',
                                             'de_CH',
                                             'dvorak',
                                             'dk',
                                             'en_US',
                                             'es',
                                             'fi',
                                             'fr',
                                             'fr_CH',
                                             'gb',
                                             'hu',
                                             'it',
                                             'intl',
                                             'jp',
                                             'no',
                                             'pl',
                                             'pt',
                                             'ru',
                                             'se',
                                             'sk',
                                             'sk_qwerty',
                                             'th',
                                             'us',
                                             'tr'
                                           ]
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys from European keyboards',
                                                       'typewriter' => 'Cyrillic layout similar to manual typewriters',
                                                       'phonetic' => 'Cyrillic layout similar to US/ASCII layout'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'typewriter',
                                                         'phonetic'
                                                       ]
                                         },
                                         [
                                           'sun',
                                           [
                                             'be',
                                             'bg',
                                             'ca',
                                             'cz',
                                             'de',
                                             'de_CH',
                                             'dvorak',
                                             'dk',
                                             'en_US',
                                             'es',
                                             'fi',
                                             'fr',
                                             'fr_CH',
                                             'gb',
                                             'hu',
                                             'it',
                                             'intl',
                                             'jp',
                                             'no',
                                             'pl',
                                             'pt',
                                             'ru',
                                             'se',
                                             'sk',
                                             'th',
                                             'us',
                                             'tr'
                                           ]
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys from European keyboards',
                                                       'typewriter' => 'Cyrillic layout similar to manual typewriters',
                                                       'phonetic' => 'Cyrillic layout similar to US/ASCII layout'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'typewriter',
                                                         'phonetic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ua'
                                         ],
                                         {
                                           'help' => {
                                                       'rstu_ru' => 'Standard RSTU on Russian layout',
                                                       'rstu' => 'Standard RSTU',
                                                       'winkeys' => 'Winkeys',
                                                       'typewriter' => 'Typewriter',
                                                       'phonetic' => 'Phonetic'
                                                     },
                                           'choice' => [
                                                         'phonetic',
                                                         'typewriter',
                                                         'winkeys',
                                                         'rstu',
                                                         'rstu_ru'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'pt'
                                         ],
                                         {
                                           'help' => {
                                                       'sundeadkeys' => 'Sun dead keys',
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'sundeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'il'
                                         ],
                                         {
                                           'help' => {
                                                       'si1452' => 'si1452',
                                                       'lyx' => 'lyx',
                                                       'phonetic' => 'Phonetic'
                                                     },
                                           'choice' => [
                                                         'lyx',
                                                         'si1452',
                                                         'phonetic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'bd'
                                         ],
                                         {
                                           'help' => {
                                                       'probhat' => 'Probhat'
                                                     },
                                           'choice' => [
                                                         'probhat'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'tr'
                                         ],
                                         {
                                           'help' => {
                                                       'alt' => 'Alt-Q',
                                                       'f' => '(F)'
                                                     },
                                           'choice' => [
                                                         'f',
                                                         'alt'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'es'
                                         ],
                                         {
                                           'help' => {
                                                       'dvorak' => 'Dvorak',
                                                       'sundeadkeys' => 'Sun dead keys',
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'sundeadkeys',
                                                         'dvorak'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ru'
                                         ],
                                         {
                                           'help' => {
                                                       'winkeys' => 'Winkeys',
                                                       'typewriter' => 'Typewriter',
                                                       'phonetic' => 'Phonetic'
                                                     },
                                           'choice' => [
                                                         'phonetic',
                                                         'typewriter',
                                                         'winkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'no'
                                         ],
                                         {
                                           'help' => {
                                                       'dvorak' => 'Dvorak',
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       'smi_nodeadkeys' => 'Northern Saami, eliminate dead keys',
                                                       'smi' => 'Northern Saami'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'dvorak',
                                                         'smi',
                                                         'smi_nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'lv'
                                         ],
                                         {
                                           'help' => {
                                                       'fkey' => 'F-letter (F) variant',
                                                       'tilde' => 'Tilde (~) variant',
                                                       'apostrophe' => 'Apostrophe (\') variant'
                                                     },
                                           'choice' => [
                                                         'apostrophe',
                                                         'tilde',
                                                         'fkey'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'latam'
                                         ],
                                         {
                                           'help' => {
                                                       'sundeadkeys' => 'Sun dead keys',
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'sundeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'fo'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'sy'
                                         ],
                                         {
                                           'help' => {
                                                       'syc' => 'Syriac',
                                                       'syc_phonetic' => 'Syriac phonetic'
                                                     },
                                           'choice' => [
                                                         'syc',
                                                         'syc_phonetic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'fr'
                                         ],
                                         {
                                           'help' => {
                                                       'dvorak' => 'Dvorak',
                                                       'latin9_nodeadkeys' => 'Alternative, eliminate dead keys',
                                                       'sundeadkeys' => 'Sun dead keys',
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       'latin9_sundeadkeys' => 'Alternative, Sun dead keys',
                                                       'latin9' => 'Alternative'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'sundeadkeys',
                                                         'latin9',
                                                         'latin9_nodeadkeys',
                                                         'latin9_sundeadkeys',
                                                         'dvorak'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ro'
                                         ],
                                         {
                                           'help' => {
                                                       'de' => 'Romanian keyboard with German letters',
                                                       'us' => 'US keyboard with Romanian letters'
                                                     },
                                           'choice' => [
                                                         'us',
                                                         'de'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'dk'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'az'
                                         ],
                                         {
                                           'help' => {
                                                       'cyrillic' => 'Cyrillic'
                                                     },
                                           'choice' => [
                                                         'cyrillic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'in'
                                         ],
                                         {
                                           'help' => {
                                                       'ben' => 'Bengali',
                                                       'tam' => 'Tamil',
                                                       'tam_unicode' => 'Tamil Unicode',
                                                       'mal' => 'Malayalam',
                                                       'guru' => 'Gurmukhi',
                                                       'kan' => 'Kannada',
                                                       'tam_TSCII' => 'Tamil TSCII Typewriter',
                                                       'guj' => 'Gujarati',
                                                       'ori' => 'Oriya',
                                                       'urd' => 'Urdu',
                                                       'tel' => 'Telugu',
                                                       'tam_TAB' => 'Tamil TAB Typewriter',
                                                       'ben_probhat' => 'Bengali Probhat'
                                                     },
                                           'choice' => [
                                                         'ben',
                                                         'ben_probhat',
                                                         'guj',
                                                         'guru',
                                                         'kan',
                                                         'mal',
                                                         'ori',
                                                         'tam_unicode',
                                                         'tam_TAB',
                                                         'tam_TSCII',
                                                         'tam',
                                                         'tel',
                                                         'urd'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'th'
                                         ],
                                         {
                                           'help' => {
                                                       'pat' => 'Pattachote',
                                                       'tis' => 'TIS-820.2538'
                                                     },
                                           'choice' => [
                                                         'tis',
                                                         'pat'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ie'
                                         ],
                                         {
                                           'help' => {
                                                       'CloGaelach' => 'CloGaelach',
                                                       'ogam_is434' => 'Ogham IS434',
                                                       'ogam' => 'Ogham',
                                                       'UnicodeExpert' => 'UnicodeExpert'
                                                     },
                                           'choice' => [
                                                         'CloGaelach',
                                                         'UnicodeExpert',
                                                         'ogam',
                                                         'ogam_is434'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'br'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'srp'
                                         ],
                                         {
                                           'help' => {
                                                       'alternatequotes' => 'With guillemots',
                                                       'latinyz' => 'Latin qwerty',
                                                       'latinunicodeyz' => 'Latin Unicode qwerty',
                                                       'latinalternatequotes' => 'Latin with guillemots',
                                                       'latinunicode' => 'Latin Unicode',
                                                       'latin' => 'Latin',
                                                       'yz' => 'Z and ZHE swapped'
                                                     },
                                           'choice' => [
                                                         'yz',
                                                         'latin',
                                                         'latinunicode',
                                                         'latinyz',
                                                         'latinunicodeyz',
                                                         'alternatequotes',
                                                         'latinalternatequotes'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'cz'
                                         ],
                                         {
                                           'help' => {
                                                       'qwerty_bksl' => 'qwerty, extended Backslash',
                                                       'bksl' => 'With &lt;\\|&gt; key',
                                                       'qwerty' => 'qwerty'
                                                     },
                                           'choice' => [
                                                         'bksl',
                                                         'qwerty',
                                                         'qwerty_bksl'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'by'
                                         ],
                                         {
                                           'help' => {
                                                       'winkeys' => 'Winkeys'
                                                     },
                                           'choice' => [
                                                         'winkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'fi'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       'smi' => 'Northern Saami'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'smi'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'lt'
                                         ],
                                         {
                                           'help' => {
                                                       'us' => 'US keyboard with Lithuanian letters',
                                                       'std' => '"Standard"'
                                                     },
                                           'choice' => [
                                                         'std',
                                                         'us'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'de'
                                         ],
                                         {
                                           'help' => {
                                                       'deadgraveacute' => 'Dead grave acute',
                                                       'ro' => 'Romanian keyboard with German letters',
                                                       'dvorak' => 'Dvorak',
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       'deadacute' => 'Dead acute',
                                                       'ro_nodeadkeys' => 'Romanian keyboard with German letters, eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'deadacute',
                                                         'deadgraveacute',
                                                         'nodeadkeys',
                                                         'ro',
                                                         'ro_nodeadkeys',
                                                         'dvorak'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'hr'
                                         ],
                                         {
                                           'help' => {
                                                       'us' => 'US keyboard with Croatian letters'
                                                     },
                                           'choice' => [
                                                         'us'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'be'
                                         ],
                                         {
                                           'help' => {
                                                       'sundeadkeys' => 'Sun dead keys',
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       'iso-alternate' => 'ISO Alternate'
                                                     },
                                           'choice' => [
                                                         'iso-alternate',
                                                         'nodeadkeys',
                                                         'sundeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ge'
                                         ],
                                         {
                                           'help' => {
                                                       'ru' => 'Russian'
                                                     },
                                           'choice' => [
                                                         'ru'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'gr'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       'polytonic' => 'Polytonic',
                                                       'extended' => 'Extended'
                                                     },
                                           'choice' => [
                                                         'extended',
                                                         'nodeadkeys',
                                                         'polytonic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'is'
                                         ],
                                         {
                                           'help' => {
                                                       'Sundeadkeys' => 'Sun dead keys',
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'Sundeadkeys',
                                                         'nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'mt'
                                         ],
                                         {
                                           'help' => {
                                                       'us' => 'US keyboard with Maltian letters'
                                                     },
                                           'choice' => [
                                                         'us'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'gb'
                                         ],
                                         {
                                           'help' => {
                                                       'intl' => 'International (with dead keys)',
                                                       'dvorak' => 'Dvorak'
                                                     },
                                           'choice' => [
                                                         'intl',
                                                         'dvorak'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ch'
                                         ],
                                         {
                                           'help' => {
                                                       'fr' => 'French',
                                                       'de_nodeadkeys' => 'German, eliminate dead keys',
                                                       'fr_sundeadkeys' => 'French, Sun dead keys',
                                                       'fr_nodeadkeys' => 'French, eliminate dead keys',
                                                       'de_sundeadkeys' => 'German, Sun dead keys'
                                                     },
                                           'choice' => [
                                                         'de_nodeadkeys',
                                                         'de_sundeadkeys',
                                                         'fr',
                                                         'fr_nodeadkeys',
                                                         'fr_sundeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'am'
                                         ],
                                         {
                                           'help' => {
                                                       'phonetic' => 'Phonetic'
                                                     },
                                           'choice' => [
                                                         'phonetic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'us'
                                         ],
                                         {
                                           'help' => {
                                                       'intl' => 'International (with dead keys)',
                                                       'dvorak' => 'Dvorak',
                                                       'alt-intl' => 'Alternative international (former us_intl)',
                                                       'rus' => 'Russian phonetic'
                                                     },
                                           'choice' => [
                                                         'intl',
                                                         'alt-intl',
                                                         'dvorak',
                                                         'rus'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'bg'
                                         ],
                                         {
                                           'help' => {
                                                       'phonetic' => 'Phonetic'
                                                     },
                                           'choice' => [
                                                         'phonetic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ee'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'mkd'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ara'
                                         ],
                                         {
                                           'help' => {
                                                       'azerty_digits' => 'azerty/digits',
                                                       'qwerty_digits' => 'qwerty/digits',
                                                       'qwerty' => 'qwerty',
                                                       'azerty' => 'azerty',
                                                       'digits' => 'digits'
                                                     },
                                           'choice' => [
                                                         'azerty',
                                                         'azerty_digits',
                                                         'digits',
                                                         'qwerty',
                                                         'qwerty_digits'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'it'
                                         ],
                                         {
                                           'help' => {
                                                       'nodeadkeys' => 'Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'hu'
                                         ],
                                         {
                                           'help' => {
                                                       'standard' => 'Standard',
                                                       '102_qwertz_comma_nodead' => '102/qwertz/comma/Eliminate dead keys',
                                                       '101_qwerty_comma_nodead' => '101/qwerty/comma/Eliminate dead keys',
                                                       '101_qwerty_dot_nodead' => '101/qwerty/dot/Eliminate dead keys',
                                                       '101_qwertz_comma_dead' => '101/qwertz/comma/Dead keys',
                                                       '101_qwerty_dot_dead' => '101/qwerty/dot/Dead keys',
                                                       '102_qwerty_comma_nodead' => '102/qwerty/comma/Eliminate dead keys',
                                                       '102_qwerty_dot_nodead' => '102/qwerty/dot/Eliminate dead keys',
                                                       '102_qwertz_dot_dead' => '102/qwertz/dot/Dead keys',
                                                       '101_qwerty_comma_dead' => '101/qwerty/comma/Dead keys',
                                                       '102_qwerty_comma_dead' => '102/qwerty/comma/Dead keys',
                                                       '102_qwertz_dot_nodead' => '102/qwertz/dot/Eliminate dead keys',
                                                       '101_qwertz_dot_nodead' => '101/qwertz/dot/Eliminate dead keys',
                                                       '102_qwerty_dot_dead' => '102/qwerty/dot/Dead keys',
                                                       '101_qwertz_dot_dead' => '101/qwertz/dot/Dead keys',
                                                       'qwerty' => 'qwerty',
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       '102_qwertz_comma_dead' => '102/qwertz/comma/Dead keys',
                                                       '101_qwertz_comma_nodead' => '101/qwertz/comma/Eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'standard',
                                                         'nodeadkeys',
                                                         'qwerty',
                                                         '101_qwertz_comma_dead',
                                                         '101_qwertz_comma_nodead',
                                                         '101_qwertz_dot_dead',
                                                         '101_qwertz_dot_nodead',
                                                         '101_qwerty_comma_dead',
                                                         '101_qwerty_comma_nodead',
                                                         '101_qwerty_dot_dead',
                                                         '101_qwerty_dot_nodead',
                                                         '102_qwertz_comma_dead',
                                                         '102_qwertz_comma_nodead',
                                                         '102_qwertz_dot_dead',
                                                         '102_qwertz_dot_nodead',
                                                         '102_qwerty_comma_dead',
                                                         '102_qwerty_comma_nodead',
                                                         '102_qwerty_dot_dead',
                                                         '102_qwerty_dot_nodead'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'ca'
                                         ],
                                         {
                                           'help' => {
                                                       'multi-2gr' => 'Multilingual, second part',
                                                       'fr-legacy' => 'French (legacy)',
                                                       'ike' => 'Inuktitut',
                                                       'multi' => 'Multilingual',
                                                       'fr-dvorak' => 'French Dvorak'
                                                     },
                                           'choice' => [
                                                         'fr-dvorak',
                                                         'fr-legacy',
                                                         'multi',
                                                         'multi-2gr',
                                                         'ike'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'pl'
                                         ],
                                         {
                                           'help' => {
                                                       'dvorak' => 'Dvorak',
                                                       'dvorak_quotes' => 'Dvorak, Polish quotes on quotemark key',
                                                       'dvorak_altquotes' => 'Dvorak, Polish quotes on key "1/!"',
                                                       'qwertz' => 'qwertz'
                                                     },
                                           'choice' => [
                                                         'qwertz',
                                                         'dvorak',
                                                         'dvorak_quotes',
                                                         'dvorak_altquotes'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'lk'
                                         ],
                                         {
                                           'help' => {
                                                       'tam_TSCII' => 'Tamil TSCII Typewriter',
                                                       'tam_unicode' => 'Tamil Unicode',
                                                       'sin_phonetic' => 'Sinhala phonetic',
                                                       'tam_TAB' => 'Tamil TAB Typewriter'
                                                     },
                                           'choice' => [
                                                         'tam_unicode',
                                                         'tam_TAB',
                                                         'tam_TSCII',
                                                         'sin_phonetic'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'se'
                                         ],
                                         {
                                           'help' => {
                                                       'dvorak' => 'Dvorak',
                                                       'rus' => 'Russian phonetic',
                                                       'nodeadkeys' => 'Eliminate dead keys',
                                                       'smi' => 'Northern Saami',
                                                       'rus_nodeadkeys' => 'Russian phonetic, eliminate dead keys'
                                                     },
                                           'choice' => [
                                                         'nodeadkeys',
                                                         'dvorak',
                                                         'rus',
                                                         'rus_nodeadkeys',
                                                         'smi'
                                                       ]
                                         },
                                         [
                                           'xorg',
                                           'sk'
                                         ],
                                         {
                                           'help' => {
                                                       'qwerty_bksl' => 'qwerty, extended Backslash',
                                                       'bksl' => 'Extended Backslash',
                                                       'qwerty' => 'qwerty'
                                                     },
                                           'choice' => [
                                                         'bksl',
                                                         'qwerty',
                                                         'qwerty_bksl'
                                                       ]
                                         }
                                       ]
                          },
                'type' => 'leaf'
              },
              'XkbOptions',
              {
                'follow' => '- XkbRules',
                'type' => 'warped_node',
                'rules' => {
                             'xorg' => {
                                         'config_class_name' => 'Xorg::InputDevice::KeyboardOptModel::Xorg'
                                       },
                             'sgi' => {
                                        'config_class_name' => 'Xorg::InputDevice::KeyboardOptModel::Sgi'
                                      },
                             'sun' => {
                                        'config_class_name' => 'Xorg::InputDevice::KeyboardOptModel::Sun'
                                      },
                             'xorg-it' => {
                                            'config_class_name' => 'Xorg::InputDevice::KeyboardOptModel::Xorg-it'
                                          }
                           }
              },
              'XkbRules',
              {
                'value_type' => 'enum',
                'help' => {
                            'xfree86' => 'Deprecated in favor of xorg'
                          },
                'default' => 'xorg',
                'type' => 'leaf',
                'choice' => [
                              'sgi',
                              'sun',
                              'xorg-it',
                              'xorg'
                            ]
              }
            ],
            'generated_by',
            'Config::Model Build.PL',
            'description',
            [
              'XkbRules',
              'specifies which XKB rules file to use for interpreting the XkbModel, XkbLayout,  XkbVariant,  and  XkbOptions settings.',
              'XkbModel',
              'specifies the XKB keyboard model name.',
              'XkbLayout',
              'specifies the XKB keyboard layout name. This is usually the country or language type of the keyboard.',
              'XkbVariant',
              'specifies the XKB keyboard variant components. These can be used to enhance the keyboard layout details.',
              'XkbOptions',
              'specifies the XKB keyboard option components. These can be used to enhance the keyboard behaviour.'
            ]
          ]
        ]
